# localslackirc
# Copyright (C) 2020 Salvo "LtWorf" Tomaselli
#
# localslackirc is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# author Salvo "LtWorf" Tomaselli <tiposchi@tiscali.it>

import os
import unittest
import subprocess


if os.path.exists("./localslackirc"):
    # inside source directory
    localslackirc = "./localslackirc"
else:
    # test installed program
    localslackirc = "localslackirc"


class TestStart(unittest.TestCase):

    def test_print_help(self):
        subprocess.check_call([localslackirc, '--help'], stdout=subprocess.DEVNULL)
